# Spitch plugin for LiveKit Agents

Support for STT and TTS with [spitch.app](https://spitch.app/).

## Installation

```bash
pip install livekit-plugins-spitch
```

## Pre-requisites

You'll need an API key from Spitch. It can be set as an environment variable: `SPITCH_API_KEY`
